'''
Author: 2-mo 1982800736@qq.com
Date: 2024-02-27 18:46:41
LastEditors: 2-mo 1982800736@qq.com
LastEditTime: 2024-02-27 18:46:53
FilePath: /a2pip/src/example_package_2-mo/example.py
Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
'''
def add_one(number):
    return number + 1